==> haskell-pandoc-lua-marshal-0.2.7-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-marshal
version:              0.2.7
visibility:           public
id:                   pandoc-lua-marshal-0.2.7-CymvWwVZ8NTKbqnKjTFfph
key:                  pandoc-lua-marshal-0.2.7-CymvWwVZ8NTKbqnKjTFfph
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  4803552143bc295570ce6a4b880670c5
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.7-CymvWwVZ8NTKbqnKjTFfph
depends:
    aeson-2.1.2.1-9BF5sjMs3G4H72EdbKHz4V base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.5
    hslua-2.3.0-3EIVejeM1ZzKH5f4L9tDgu
    hslua-list-1.1.3-E7NtmTd5XLjDiHSs6b7CIp
    hslua-marshalling-2.3.1-9mmGA2NSwpxIKMAzIMvWOU
    pandoc-types-1.23.1-BDeGY15alNe7G2DUW4nUuI
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-marshal-0.2.7-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-marshal
version:              0.2.7
visibility:           public
id:                   pandoc-lua-marshal-0.2.7-89ZJJ9uebotCy7RdwS87eh
key:                  pandoc-lua-marshal-0.2.7-89ZJJ9uebotCy7RdwS87eh
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  36474dd4dbfa5359f37ab6ab33318c42
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.7-89ZJJ9uebotCy7RdwS87eh
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.5
    hslua-2.3.0-DeYTtc0IN4k7P3FpQ75nvr
    hslua-list-1.1.3-D0OsRlpSaMK4a4SfYcace
    hslua-marshalling-2.3.1-IgtCsiHhYGy5iz5DZtbSV9
    pandoc-types-1.23.1-ELe8Jbe7bs1Ct2CeL2T43a
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
